@@ -13,8 +13,6 @@ class MlPlatformException(Exception):
 
 
 class ApiClient:
-    SECRET_LIST = ["projectId", "userId", "accessToken", "refreshToken", "authorizationType"]
-
     def __init__(self, server_config_path: str = None):
         # server_config_path가 none이면 pod에서 수행된다고 간주
         # 공용으로 사용하는 env 및 secret을 로드한다.
@@ -29,6 +27,7 @@ class ApiClient:
 
     def load_env(self):
         self.hyperdata_addr = os.environ["hyperdataAddr"]
+        self.proauth_addr = os.environ["proauthAddr"]
         self.experiment_id = os.environ["experimentId"]
         self.train_id = os.environ["trainId"] if "trainId" in os.environ else None
         self.inference_id = os.environ["inferenceId"] if "inferenceId" in os.environ else None
@@ -37,15 +36,6 @@ class ApiClient:
         self.serving_mount_path = os.environ["servingMountPath"] if "servingMountPath" in os.environ else None
         self.secret_mount_path = os.environ["secretMountPath"]
         file_list = [f for f in os.listdir(self.secret_mount_path)]
-        for secret in self.SECRET_LIST:
-            if secret not in file_list:
-                print(f'Cannot found "{secret}" in secret path "{self.secret_mount_path}".')
-                exit(1)
-
-        for file in file_list:
-            if file in self.SECRET_LIST:
-                setattr(self, file, open(os.path.join(self.secret_mount_path, file), "r").read())
-        self.Authorization = self.accessToken
 
     def load_server_config(self, server_config_path):
         server_config = yaml.safe_load(open(server_config_path, "r"))
