@@ -1,16 +1,27 @@
 import os
+from mlplatform_lib.api_client import RunMode
 
-class Auth():
+
+class Auth:
     SECRET_LIST = ["projectId", "userId", "accessToken", "refreshToken", "authorizationType"]
 
-    def __new__(cls):
-        if not hasattr(cls, 'instance'):
+    def __new__(cls, *args, **kwargs):
+        if not hasattr(cls, "instance"):
             cls.instance = super(Auth, cls).__new__(cls)
         return cls.instance
 
     def __init__(self, *args, **kwargs):
-        self.secret_mount_path = os.environ["secretMountPath"]
-        self.load_env(self.secret_mount_path)
+        api_client = kwargs.get("api_client")
+
+        if api_client.run_mode == RunMode.LOCAL:
+            self.secret_mount_path = None
+            self.authorization = api_client.Authorization
+            self.projectId = api_client.projectId
+            self.userId = api_client.userId
+            self.refreshToken = api_client.refreshToken
+        else:
+            self.secret_mount_path = os.environ["secretMountPath"]
+            self.load_env(self.secret_mount_path)
 
     def load_env(self, secret_mount_path):
         file_list = [f for f in os.listdir(self.secret_mount_path)]
