@@ -10,7 +10,6 @@ from mlplatform_lib.dataclass.experiment.type import ExperimentType
 from mlplatform_lib.dataclass.model import ModelInfoDto, ModelAutomlDto, ModelAutomlBestDto
 from mlplatform_lib.dataclass.model.type import ModelStatus
 from mlplatform_lib.hyperdata import HyperdataApi
-from mlplatform_lib.mlplatform.mlplatform_http_client import MlPlatformUserAuth
 
 
 class AutomlApi:
@@ -20,7 +19,9 @@ class AutomlApi:
         self.api_client = api_client
 
         if api_client.run_mode == RunMode.KUBERNETES:
-            self.automl_client = AutomlHttpClient(mlplatform_addr=os.environ["mlplatformAddr"])
+            self.automl_client = AutomlHttpClient(
+                mlplatform_addr=os.environ["mlplatformAddr"], api_client=self.api_client
+            )
             self.hyperdata_api = HyperdataApi(api_client=self.api_client)
         self.experiment_id = self.api_client.experiment_id
         self.train_id = self.api_client.train_id
@@ -29,9 +30,7 @@ class AutomlApi:
 
     def get_models(self) -> Optional[List[ModelAutomlDto]]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
-            return self.automl_client.get_models(
-                experiment_id=self.experiment_id, train_id=self.train_id,
-            )
+            return self.automl_client.get_models(experiment_id=self.experiment_id, train_id=self.train_id,)
         else:
             print("Current mode is local, Skip get_models.")
             return None
@@ -42,9 +41,7 @@ class AutomlApi:
             model.status = ModelStatus.SUCCESS
             model.experiment_type = ExperimentType.AUTOML
             return self.automl_client.insert_model(
-                experiment_id=self.experiment_id,
-                train_id=self.train_id,
-                model=model,
+                experiment_id=self.experiment_id, train_id=self.train_id, model=model,
             )
         else:
             print("Current mode is local, Skip insert_model.")
@@ -67,19 +64,12 @@ class AutomlApi:
             print("Current mode is local, Skip insert_visualizations.")
 
     def _get_inference_result_table_name(self) -> str:
-        automl_experiment_dto = self.automl_client.get_experiment(
-            experiment_id=self.experiment_id
-        )
+        automl_experiment_dto = self.automl_client.get_experiment(experiment_id=self.experiment_id)
 
         return f"AUTOML_{automl_experiment_dto.name}_{str(automl_experiment_dto.id)}"
 
     def upload_inference_csv(self, inference_csv_path: str):
-        if self.api_client == RunMode.KUBERNETES:
-            self.automl_client.upload_inference_csv(
-                experiment_id=self.experiment_id,
-                inference_id=self.inference_id,
-                inference_csv_path=inference_csv_path,
-            )
+        if self.api_client.run_mode == RunMode.KUBERNETES:
             inference_data = pd.read_csv(inference_csv_path)
 
             table_name = self._get_inference_result_table_name()
@@ -94,9 +84,7 @@ class AutomlApi:
             )
 
             self.hyperdata_api.hyperdata_client.insert_dataobject_tuple(
-                auth=self.hyperdata_api.hyperdata_auth,
-                dataobject_id=self.target_do_id,
-                insert_tuple_objects=insert_tuple_object,
+                dataobject_id=self.target_do_id, insert_tuple_objects=insert_tuple_object,
             )
 
             automl_inference_dto = self.automl_client.get_inference(
@@ -105,8 +93,7 @@ class AutomlApi:
 
             automl_inference_dto.target_do_id = self.target_do_id
             self.automl_client.update_inference(
-                experiment_id=self.experiment_id,
-                inference_automl_dto=automl_inference_dto,
+                experiment_id=self.experiment_id, inference_automl_dto=automl_inference_dto,
             )
             os.remove(inference_csv_path)
         else:
@@ -115,9 +102,7 @@ class AutomlApi:
     def insert_model_automl_best(self, model_automl_best: ModelAutomlBestDto) -> ModelAutomlBestDto:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             return self.automl_client.insert_model_automl_best(
-                experiment_id=self.experiment_id,
-                train_id=self.train_id,
-                model_automl_best=model_automl_best,
+                experiment_id=self.experiment_id, train_id=self.train_id, model_automl_best=model_automl_best,
             )
         else:
             print("Current mode is local, Skip insert_model_automl_best.")
