@@ -13,16 +13,12 @@ from mlplatform_lib.dataclass.inference.inference_automl_dto import InferenceAut
 
 
 class AutomlHttpClient(MlPlatformHttpClient):
-    def __init__(self, mlplatform_addr):
-        super().__init__(mlplatform_addr=mlplatform_addr)
+    def __init__(self, mlplatform_addr, api_client):
+        super().__init__(mlplatform_addr=mlplatform_addr, api_client=api_client)
 
     def get_models(self, experiment_id: int, train_id: int) -> List[ModelAutomlDto]:
         res = self.send_request(
-            "models",
-            {"experiments": experiment_id, "trains": train_id},
-            {},
-            {},
-            MlPlatformRequestType.READ,
+            "models", {"experiments": experiment_id, "trains": train_id}, {}, {}, MlPlatformRequestType.READ,
         )
         model_infos = []
         for model_info in res.data:
@@ -30,14 +26,10 @@ class AutomlHttpClient(MlPlatformHttpClient):
         return model_infos
 
     def get_experiment(self, experiment_id: int) -> ExperimentAutomlDto:
-        result = self.send_request(
-            "", {"experiments": experiment_id}, {}, {}, MlPlatformRequestType.READ
-        )
+        result = self.send_request("", {"experiments": experiment_id}, {}, {}, MlPlatformRequestType.READ)
         return from_dict(ExperimentAutomlDto, result.data)
 
-    def get_inference(
-        self, experiment_id: int, inference_id: int
-    ) -> InferenceAutomlDto:
+    def get_inference(self, experiment_id: int, inference_id: int) -> InferenceAutomlDto:
         result = self.send_request(
             "",
             {"experiments": experiment_id, "inferences": inference_id},
@@ -59,9 +51,7 @@ class AutomlHttpClient(MlPlatformHttpClient):
         )
         return from_dict(InferenceAutomlDto, result.data)
 
-    def insert_model(
-        self, experiment_id: int, train_id: int, model: ModelAutomlDto
-    ) -> ModelAutomlDto:
+    def insert_model(self, experiment_id: int, train_id: int, model: ModelAutomlDto) -> ModelAutomlDto:
         res = self.send_request(
             "models",
             {"experiments": experiment_id, "trains": train_id},
@@ -72,10 +62,7 @@ class AutomlHttpClient(MlPlatformHttpClient):
         return from_dict(ModelAutomlDto, res.data)
 
     def insert_model_automl_best(
-        self,
-        experiment_id: int,
-        train_id: int,
-        model_automl_best: ModelAutomlBestDto,
+        self, experiment_id: int, train_id: int, model_automl_best: ModelAutomlBestDto,
     ) -> ModelAutomlBestDto:
         result = self.send_request(
             "model-automl-bests",
