@@ -8,6 +8,10 @@ from .table_desc_info import TableDescInfo
 from .data_object_info_list import DataObjectInfoList
 from .db_source_data_object_candidate import DbSourceDataObjectCandidate
 from .db_source_data_object_candidate_list import DbSourceDataObjectCandidateList
+from .column_option import ColumnOption
+from .row_option import RowOption
+from .selector_property import SelectorProperty
+from .file_download import FileDownload
 
 __all__ = [
     "DataObjectOutCol",
@@ -20,4 +24,8 @@ __all__ = [
     "DataObjectInfoList",
     "DbSourceDataObjectCandidate",
     "DbSourceDataObjectCandidateList",
+    "FileDownload",
+    "SelectorProperty",
+    "RowOption",
+    "ColumnOption",
 ]
