@@ -4,3 +4,5 @@ from dataclasses import dataclass
 @dataclass
 class DataObjectOutCol:
     name: str
+    type: str
+    type_change: str
