@@ -6,4 +6,4 @@ from mlplatform_lib.dataclass.experiment.type import ExperimentType
 class InferenceDto:
     id: int = field(init=False, default=0)
     experiment_type: ExperimentType = field(init=False)
-    model_path: str
+    inference_path: str
