@@ -9,7 +9,6 @@ from mlplatform_lib.dataclass import (
 )
 from mlplatform_lib.hyperdata.hyperdata_http_client import (
     HyperdataHttpClient,
-    HyperdataUserAuth,
     HYPERDATA_DATETIME_FORMAT,
 )
 from mlplatform_lib.hyperdata.hyperdata_local_checker import HyperdataLocalChecker
@@ -31,8 +30,11 @@ class HyperdataApi:
             self.api_client.projectId = self.local_checker.project_id
             self.api_client.userId = self.api_client.user_id
             self.api_client.Authorization = self.local_checker.access_token
+            self.api_client.refreshToken = self.local_checker.refresh_token
 
-        self.hyperdata_client = HyperdataHttpClient(hd_addr=self.api_client.hyperdata_addr,api_client=api_client)
+        self.hyperdata_client = HyperdataHttpClient(
+            hd_addr=self.api_client.hyperdata_addr, api_client=api_client
+        )
 
     def download_csv(self, do_id: int, data_rootpath: str) -> str:
         result, sep, line_delim = self.hyperdata_client.download_do_to_csv(do_id)
@@ -53,14 +55,11 @@ class HyperdataApi:
         return csv_path
 
     def create_inference_result(self, table_name: str, object_name: str, columns: List[str]) -> int:
-        default_datasource_id = self.hyperdata_client.get_default_datasource_id(auth=self.hyperdata_auth)
-        table_list = self.hyperdata_client.get_dataobject_tables(
-            auth=self.hyperdata_auth, datasource_id=default_datasource_id
-        )
+        default_datasource_id = self.hyperdata_client.get_default_datasource_id()
+        table_list = self.hyperdata_client.get_dataobject_tables(datasource_id=default_datasource_id)
 
         if table_name not in [table_info.name for table_info in table_list.db_source_data_object_candidate]:
             self.hyperdata_client.create_dataobject_table(
-                auth=self.hyperdata_auth,
                 datasource_id=default_datasource_id,
                 table_from_default_data_source=TableFromDefaultDataSourceInfo(
                     table_name=table_name,
@@ -74,13 +73,11 @@ class HyperdataApi:
             print(f"table {table_name} already exists. skip create dataobject table")
 
         do_info_list = self.hyperdata_client.get_do_list_by_datasource_id(
-            auth=self.hyperdata_auth,
-            datasource_id=self.hyperdata_client.get_default_datasource_id(auth=self.hyperdata_auth),
+            datasource_id=self.hyperdata_client.get_default_datasource_id(),
         )
 
         if object_name not in [object_info.name for object_info in do_info_list.data_object_info_list]:
             do_info_list = self.hyperdata_client.create_dataobjects(
-                auth=self.hyperdata_auth,
                 datasource_id=default_datasource_id,
                 dataobjects=DataObjectInfoList(
                     data_object_info_list=[
@@ -89,7 +86,7 @@ class HyperdataApi:
                             name=object_name,
                             source_table_name=table_name,
                             subtype="Inference Result",
-                            out_cols=[DataObjectOutCol(name=column) for column in columns],
+                            out_cols=[DataObjectOutCol(name=column, type="VARCHAR", type_change="VARCHAR") for column in columns],
                             share_relation=[],
                             author="",
                             description="",
