@@ -6,6 +6,9 @@ from mlplatform_lib.dataclass import (
     DataObjectInfoList,
     DbSourceDataObjectCandidate,
     DbSourceDataObjectCandidateList,
+    FileDownload,
+    SelectorProperty,
+    ColumnOption,
 )
 from dataclasses import dataclass
 from enum import Enum
@@ -16,6 +19,7 @@ from mlplatform_lib.utils.dataclass_utils import from_dict, to_dict
 from mlplatform_lib.api_client import ApiClient
 from mlplatform_lib.auth import Auth
 from mlplatform_lib.proauth.proauth_http_client import ProauthHttpClient
+import base64
 
 
 HYPERDATA_DATETIME_FORMAT = "%Y.%m.%d %H.%M.%S"
@@ -58,6 +62,7 @@ class HyperdataRequestResult:
 class HyperdataHttpClient:
     def __init__(self, hd_addr, api_client: ApiClient):
         self.base_url = hd_addr + "/hyperdata/web-service"
+        self.api_client = api_client
         self.proauth_client = ProauthHttpClient(proauth_addr=api_client.proauth_addr)
 
     def send_request(
@@ -68,7 +73,7 @@ class HyperdataHttpClient:
         data: Optional[dict],
         request_type: HyperdataRequestType,
     ) -> HyperdataRequestResult:
-        auth = Auth()
+        auth = Auth(api_client=self.api_client)
         headers = {
             "Content-Type": "application/json",
             "Authorization": auth.authorization,
@@ -88,8 +93,7 @@ class HyperdataHttpClient:
             headers["doType"] = "inferenceResult"
 
         if request_type == HyperdataRequestType.DOWNLOAD:
-            headers["ProObjectWebFileTransfer"] = "true"
-            query["action"] = "Download"
+            headers["Content-Type"] = "application/octet-stream"
 
         url = self.base_url + "/projects/" + str(auth.projectId)
         for key, val in rest.items():
@@ -130,7 +134,7 @@ class HyperdataHttpClient:
                     response.json(), response.content.decode(), response.status_code
                 )
         else:
-            if response.json()['exception']['code'] == "HDE-0403":
+            if response.json()["exception"]["code"] == "HDE-0403":
                 result, refresh_token, access_token = self.proauth_client.update_token(auth.refreshToken)
                 if result == "true":
                     auth.refreshToken = refresh_token
@@ -138,7 +142,10 @@ class HyperdataHttpClient:
                     auth.authorization = access_token
                     headers["Authorization"] = auth.accessToken
 
-                    if request_type == HyperdataRequestType.READ or request_type == HyperdataRequestType.DOWNLOAD:
+                    if (
+                        request_type == HyperdataRequestType.READ
+                        or request_type == HyperdataRequestType.DOWNLOAD
+                    ):
                         response = requests.get(url, headers=headers, data=json.dumps(data), verify=False)
                     elif request_type == HyperdataRequestType.CREATE:
                         response = requests.post(url, headers=headers, data=json.dumps(data), verify=False)
@@ -153,8 +160,8 @@ class HyperdataHttpClient:
 
                 else:
                     raise HyperdataRequestException(response.content.decode(), response.status_code)
-                
-            else:    
+
+            else:
                 print(response.content.decode())
                 print(
                     (
@@ -166,9 +173,7 @@ class HyperdataHttpClient:
 
     # TODO: hyperdata datasource에 do 정보들을 다가지고 오는 so 구현 필요
     def get_do_list(self) -> List[DataObject]:
-        result = self.send_request(
-            "automlExperimentDataObjectList", {}, {}, {}, HyperdataRequestType.READ
-        )
+        result = self.send_request("automlExperimentDataObjectList", {}, {}, {}, HyperdataRequestType.READ)
         result_data = result.data["dto"]["dataObjectInfoList"]
 
         do_list = []
@@ -177,18 +182,16 @@ class HyperdataHttpClient:
         return do_list
 
     def get_do_simple_list(self) -> dict:
-        result = self.send_request(
-            "automlExperimentDataObjectList", {}, {}, {}, HyperdataRequestType.READ
-        )
+        result = self.send_request("automlExperimentDataObjectList", {}, {}, {}, HyperdataRequestType.READ)
         result_data = result.data["dto"]["dataObjectInfoList"]
         do_list = {}
         for do_info in result_data:
             do_list[do_info["name"]] = do_info["id"]
         return do_list
 
-    def get_do_list_by_datasource_id(self, auth: HyperdataUserAuth, datasource_id: int) -> DataObjectInfoList:
+    def get_do_list_by_datasource_id(self, datasource_id: int) -> DataObjectInfoList:
         result = self.send_request(
-            "dataobjects", {"datasources": datasource_id}, {}, {}, auth, HyperdataRequestType.READ
+            "dataobjects", {"datasources": datasource_id}, {}, {}, HyperdataRequestType.READ
         )
         result_data = result.data["dto"]["dataObjectInfoList"]
         return DataObjectInfoList(
@@ -201,7 +204,7 @@ class HyperdataHttpClient:
         )
         return from_dict(DataObject, result.data["dto"])
 
-    #    def get_do_samples(self, auth: HyperdataUserAuth, dataobject_id: int, sample_size: int):
+    #    def get_do_samples(self, dataobject_id: int, sample_size: int):
     #        return self.send_request(
     #            "",
     #            {"dataobjects": dataobject_id},
@@ -212,9 +215,7 @@ class HyperdataHttpClient:
     #        )
 
     # 아직 공식 hyperdata so에서 값이 이상하게 들어와 직접 만든걸 사용
-    def get_do_samples(
-        self, dataobject_id: int, sample_size: int
-    ) -> HyperdataRequestResult:
+    def get_do_samples(self, dataobject_id: int, sample_size: int) -> HyperdataRequestResult:
         result = self.send_request(
             "automlExperimentDataObjectSample",
             {"dataobjects": dataobject_id},
@@ -231,92 +232,75 @@ class HyperdataHttpClient:
         result.data["dto"]["tableString"] = json.dumps(fixed_table_string)
         return result
 
-    def get_do_detail_info(self, do_id: int):
+    def get_do_detail_info(self, do_id: int, subtype: str = "Table"):
         result = self.send_request(
             "",
-            {"isedit": 0, "subtype": "Table", "dataobjects": do_id},
+            {"isedit": 0, "subtype": subtype, "dataobjects": do_id},
             {"action": "Desc"},
             {},
             HyperdataRequestType.READ,
         )
         return from_dict(TableDescInfo, result.data["dto"])
 
-    def download_do_to_csv(
-        self, do_id: int
-    ) -> Tuple[HyperdataRequestResult, str, str]:
-        result = self.send_request(
-            "", {"dataobjects": do_id}, {"action": "Detail"}, {}, HyperdataRequestType.READ,
+    def download_do_to_csv(self, do_id: int) -> Tuple[HyperdataRequestResult, str, str]:
+        # 1. get do info
+        data_object = self.get_do_info(do_id=do_id)
+        # 2. get do detail info
+        table_desc_info = self.get_do_detail_info(do_id=do_id, subtype=data_object.subtype)
+
+        # 3. create do to csv in hyperdata
+        file_download = FileDownload(
+            file_name=data_object.name,
+            file_type="csv",
+            selector_property=SelectorProperty(
+                column_select_options=[
+                    ColumnOption(name=col_info.name, alias=col_info.alias, type="VARCHAR")
+                    for col_info in table_desc_info.col_info_list
+                ],
+                row_select_options=[],
+            ),
+            file_token=None,
         )
 
-        table_name = result.data["dto"]["sourceTableName"]
-        subtype = result.data["dto"]["subtype"]
-        datasource_id = result.data["dto"]["datasourceId"]
+        result = self.send_request(
+            "",
+            {"dataobjects": do_id},
+            {"action": "FileCreateWithOptions"},
+            to_dict(file_download),
+            HyperdataRequestType.CREATE,
+        )
+        file_download = from_dict(FileDownload, result.data["dto"])
 
-        def _download_do_to_csv():
-            result = self.send_request(
+        auth = Auth(api_client=self.api_client)
+        download_info = (
+            f"Authorization::{auth.authorization}"
+            f"::userId::{auth.userId}"
+            f"::dataObjectId::{data_object.id}"
+            f"::filePath::{data_object.name}.csv"
+            f"::fileToken::{file_download.file_token}"
+        )
+
+        # 4. download csv file
+        download_info_encoded_str = base64.b64encode(download_info.encode("utf-8")).decode("utf-8")
+        return (
+            self.send_request(
                 "",
-                {"isedit": 0, "subtype": subtype, "dataobjects": do_id},
-                {"action": "Desc"},
+                {"dataobjects": download_info_encoded_str},
+                {"action": "FileSecureDownload"},
                 {},
-                HyperdataRequestType.READ,
-            )
-            cols = result.data["dto"]["colInfoList"]
-            col_select_opts = []
-            for col in cols:
-                col_select_opts.append(
-                    {"type": col["type"], "alias": col["alias"], "name": col["alias"], "userExpr": ""}
-                )
-            return self.send_request(
-                "",
-                {"dataobjects": do_id},
-                {},
-                {
-                    "id": "task1",
-                    "name": "1",
-                    "itemId": "selector",
-                    "inputTables": [{"name": table_name, "cols": cols}],
-                    "selectorProperty": {"columnSelectOptions": col_select_opts, "rowSelectOptions": []},
-                    "outputTable": {"name": table_name},
-                },
                 HyperdataRequestType.DOWNLOAD,
-            )
-
-        result = self.send_request(
-            "", {"datasources": datasource_id}, {"action": "Detail"}, {}, HyperdataRequestType.READ,
+            ),
+            ",",
+            "\\n",
         )
-        do_type_check = None
-        try:
-            do_type_check = (
-                "fileSourceParam" in result.data["dto"]
-                and "fileType" in result.data["dto"]["fileSourceParam"]
-                and result.data["dto"]["fileSourceParam"]["fileType"] is not None
-                and result.data["dto"]["fileSourceParam"]["fileType"].lower().find("sam") != -1
-            )
-        except Exception:
-            return _download_do_to_csv(), ",", "\\n"
-
-        if do_type_check:
-            return (
-                self.send_request(
-                    "automlDataObjectCSV",
-                    {"dataobjects": do_id},
-                    {"action": "Download"},
-                    {},
-                    HyperdataRequestType.DOWNLOAD,
-                ),
-                result.data["dto"]["fileSourceParam"]["fieldDelimiter"],
-                result.data["dto"]["fileSourceParam"]["lineDelimiter"],
-            )
-        else:
-            return _download_do_to_csv(), ",", "\\n"
 
     def get_default_datasource_id(self) -> int:
         result = self.send_request("dataSourceDefault", {}, {}, {}, HyperdataRequestType.READ)
         return int(result.data["dto"]["defaultDataSourceId"])
 
-    def get_dataobject_tables(self, auth: HyperdataUserAuth, datasource_id: int):
+    def get_dataobject_tables(self, datasource_id: int):
         result = self.send_request(
-            "", {"datasources": datasource_id}, {"action": "Desc"}, {}, auth, HyperdataRequestType.READ
+            "", {"datasources": datasource_id}, {"action": "Desc"}, {}, HyperdataRequestType.READ
         )
 
         result_data = result.data["dto"]["DbSourceDataObjectCandidate"]
@@ -327,9 +311,7 @@ class HyperdataHttpClient:
         )
 
     def create_dataobject_table(
-        self,
-        datasource_id: int,
-        table_from_default_data_source: TableFromDefaultDataSourceInfo,
+        self, datasource_id: int, table_from_default_data_source: TableFromDefaultDataSourceInfo,
     ) -> None:
         self.send_request(
             "dataobjects",
@@ -339,9 +321,7 @@ class HyperdataHttpClient:
             HyperdataRequestType.CREATE,
         )
 
-    def create_dataobjects(
-        self, datasource_id: int, dataobjects: DataObjectInfoList
-    ) -> DataObjectInfoList:
+    def create_dataobjects(self, datasource_id: int, dataobjects: DataObjectInfoList) -> DataObjectInfoList:
         result = self.send_request(
             "dataobjects",
             {"datasources": datasource_id},
