@@ -9,8 +9,8 @@ from typing import List
 
 
 class MllabHttpClient(MlPlatformHttpClient):
-    def __init__(self, mlplatform_addr):
-        super().__init__(mlplatform_addr=mlplatform_addr)
+    def __init__(self, mlplatform_addr, api_client):
+        super().__init__(mlplatform_addr=mlplatform_addr, api_client=api_client)
 
     def get_model_list(self, experiment_id: int) -> List[ModelDto]:
         res = self.send_request(
