@@ -28,7 +28,9 @@ class MlPlatformApi:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             self.mlplatform_addr = os.environ["mlplatformAddr"]
 
-            self.mlplatform_client = MlPlatformHttpClient(mlplatform_addr=self.mlplatform_addr)
+            self.mlplatform_client = MlPlatformHttpClient(
+                mlplatform_addr=self.mlplatform_addr, api_client=api_client
+            )
             self.train_do_id = int(os.environ["doId"]) if "doId" in os.environ else None
             self.inference_do_id = int(os.environ["doId"]) if "doId" in os.environ else None
             self.mount_path = self.api_client.pvc_mount_path
@@ -91,8 +93,5 @@ class MlPlatformApi:
 
     def insert_model_info(self, model_id: int, model_info: ModelInfoDto) -> ModelInfoDto:
         return self.mlplatform_client.insert_model_info(
-            experiment_id=self.experiment_id,
-            train_id=self.train_id,
-            model_id=model_id,
-            model_info=model_info
+            experiment_id=self.experiment_id, train_id=self.train_id, model_id=model_id, model_info=model_info
         )
