@@ -44,8 +44,9 @@ class MlPlatformRequestResult:
 
 
 class MlPlatformHttpClient:
-    def __init__(self, mlplatform_addr):
+    def __init__(self, mlplatform_addr, api_client):
         self.base_url = mlplatform_addr
+        self.api_client = api_client
 
     def send_request(
         self,
@@ -55,8 +56,8 @@ class MlPlatformHttpClient:
         data: Union[Optional[dict], Path],
         request_type: MlPlatformRequestType,
     ) -> MlPlatformRequestResult:
-        auth = Auth()
-        
+        auth = Auth(api_client=self.api_client)
+
         headers = {
             "Content-Type": "application/json",
             "Authorization": auth.authorization,
@@ -114,9 +115,7 @@ class MlPlatformHttpClient:
             )
             raise MlPlatformRequestException(response.content.decode(), response.status_code)
 
-    def upload_inference_csv(
-        self, experiment_id: int, inference_id: int, inference_csv_path: str
-    ) -> None:
+    def upload_inference_csv(self, experiment_id: int, inference_id: int, inference_csv_path: str) -> None:
         self.send_request(
             "file",
             {"experiments": experiment_id, "inferences": inference_id},
@@ -126,11 +125,7 @@ class MlPlatformHttpClient:
         )
 
     def insert_model_info(
-        self,
-        experiment_id: int,
-        train_id: int,
-        model_id: int,
-        model_info: ModelInfoDto
+        self, experiment_id: int, train_id: int, model_id: int, model_info: ModelInfoDto
     ) -> ModelInfoDto:
         model_info.finished_time = datetime.now().strftime(MLPLATFORM_TIMSTAMP_FORMAT)
 
