@@ -3,7 +3,6 @@ from mlplatform_lib.dataclass.experiment.type import ExperimentType
 from mlplatform_lib.dataclass.model.type import ModelStatus
 from mlplatform_lib.dataclass.model import ModelPredefinedaiDto, ModelInfoDto
 from mlplatform_lib.dataclass import InsertTupleObject
-from mlplatform_lib.mlplatform.mlplatform_http_client import MlPlatformUserAuth
 from mlplatform_lib.predefinedai.predefinedai_http_client import PredefinedAIHttpClient
 import os
 from typing import List, Optional
@@ -18,15 +17,10 @@ class PredefinedAIApi:
         self.api_client = api_client
 
         if api_client.run_mode == RunMode.KUBERNETES:
-            self.predefinedai_client = PredefinedAIHttpClient(mlplatform_addr=os.environ["mlplatformAddr"])
-            self.hyperdata_api = HyperdataApi(api_client=self.api_client)
-
-            self.mlplatform_auth = MlPlatformUserAuth(
-                project_id=self.api_client.projectId,
-                user_id=self.api_client.userId,
-                authorization=self.api_client.Authorization,
-                authorization_type=self.api_client.authorizationType,
+            self.predefinedai_client = PredefinedAIHttpClient(
+                mlplatform_addr=os.environ["mlplatformAddr"], api_client=self.api_client
             )
+            self.hyperdata_api = HyperdataApi(api_client=self.api_client)
 
         self.experiment_id = self.api_client.experiment_id
         self.train_id = self.api_client.train_id
@@ -36,9 +30,7 @@ class PredefinedAIApi:
     def get_models(self) -> Optional[List[ModelPredefinedaiDto]]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             return self.predefinedai_client.get_model_infos(
-                experiment_id=self.api_client.experiment_id,
-                train_id=self.api_client.train_id,
-                auth=self.mlplatform_auth,
+                experiment_id=self.api_client.experiment_id, train_id=self.api_client.train_id
             )
         else:
             print("Current mode is local, Skip get_model_infos.")
@@ -50,10 +42,7 @@ class PredefinedAIApi:
             model.status = ModelStatus.SUCCESS
             model.experiment_type = ExperimentType.PREDEFINEDAI
             return self.predefinedai_client.insert_model(
-                experiment_id=self.experiment_id,
-                train_id=self.train_id,
-                model=model,
-                auth=self.mlplatform_auth,
+                experiment_id=self.experiment_id, train_id=self.train_id, model=model
             )
         else:
             print("Current mode is local, Skip insert_model_info.")
@@ -71,15 +60,12 @@ class PredefinedAIApi:
                 train_id=self.train_id,
                 model_id=model_id,
                 model_info=model_info,
-                auth=self.mlplatform_auth,
             )
         else:
             print("Current mode is local, Skip insert_visualizations.")
 
     def _get_inference_result_table_name(self) -> str:
-        pdai_experiment_dto = self.predefinedai_client.get_experiment(
-            experiment_id=self.experiment_id, auth=self.mlplatform_auth
-        )
+        pdai_experiment_dto = self.predefinedai_client.get_experiment(experiment_id=self.experiment_id)
 
         return f"PREDEFINEDAI_{pdai_experiment_dto.name}_{str(pdai_experiment_dto.id)}"
 
@@ -100,19 +86,15 @@ class PredefinedAIApi:
             )
 
             self.hyperdata_api.hyperdata_client.insert_dataobject_tuple(
-                auth=self.hyperdata_api.hyperdata_auth,
-                dataobject_id=self.target_do_id,
-                insert_tuple_objects=insert_tuple_object,
+                dataobject_id=self.target_do_id, insert_tuple_objects=insert_tuple_object,
             )
 
             pdai_inference_dto = self.predefinedai_client.get_inference(
-                experiment_id=self.experiment_id, inference_id=self.inference_id, auth=self.mlplatform_auth
+                experiment_id=self.experiment_id, inference_id=self.inference_id
             )
             pdai_inference_dto.target_do_id = self.target_do_id
             self.predefinedai_client.update_inference(
-                experiment_id=self.experiment_id,
-                inference_predefinedai_dto=pdai_inference_dto,
-                auth=self.mlplatform_auth,
+                experiment_id=self.experiment_id, inference_predefinedai_dto=pdai_inference_dto
             )
 
             os.remove(inference_csv_path)
