@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Dict, List
 import inspect
 import inflection
 from dataclasses import is_dataclass
@@ -17,7 +17,22 @@ def from_dict(dataclass, dict: Dict):
         key = inflection.underscore(key)
 
         if key in sig.parameters.keys():
-            init_dict[key] = val
+            key_class = sig.parameters[key].annotation
+            if is_dataclass(key_class):
+                init_dict[key] = from_dict(sig.parameters[key].annotation, val)
+            # regard as typing hint
+            elif hasattr(key_class, "__origin__") and (
+                key_class.__origin__ == list or key_class.__origin__ == List
+            ):
+                if is_dataclass(sig.parameters[key].annotation.__args__[0]):
+                    init_dict[key] = [
+                        from_dict(sig.parameters[key].annotation.__args__[0], elem) for elem in val
+                    ]
+                else:
+                    init_dict[key] = val
+
+            else:
+                init_dict[key] = val
         else:
             init_false_dict[key] = val
 
